==> applicationinsights-core-1.0.5-sources.jar: com/microsoft/applicationinsights/internal/config/TelemetryProcessorXmlElement.java <==
/*
 * ApplicationInsights-Java
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the ""Software""), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.microsoft.applicationinsights.internal.config;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;

/**
 * Created by gupele on 7/26/2016.
 */
@XmlRootElement(name="Processor")
public class TelemetryProcessorXmlElement {
    private String type;
    private ArrayList<ParamXmlElement> adds;

    public ArrayList<ParamXmlElement> getAdds() {
        return adds;
    }

    @XmlElement(name="Add")
    public void setAdds(ArrayList<ParamXmlElement> adds) {
        this.adds = adds;
    }

    @XmlAttribute
    public String getType() {
        return type;
    }

    public void setType(String type){
        this.type = type;
    }
}

==> applicationinsights-core-2.0.1-sources.jar: com/microsoft/applicationinsights/internal/config/TelemetryProcessorXmlElement.java <==
/*
 * ApplicationInsights-Java
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the ""Software""), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.microsoft.applicationinsights.internal.config;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;

/**
 * Created by gupele on 7/26/2016.
 */
@XmlRootElement(name="Processor")
public class TelemetryProcessorXmlElement {
    private String type;
    private ArrayList<ParamXmlElement> adds = new ArrayList<ParamXmlElement>();
    private ParamExcludedTypeXmlElement excludedTypes;
    private ParamIncludedTypeXmlElement includedTypes;

    public ParamExcludedTypeXmlElement getExcludedTypes() {
        return excludedTypes;
    }

    @XmlElement(name = "ExcludedTypes")
    public void setExcludedTypes(ParamExcludedTypeXmlElement excludedTypes) {
        this.excludedTypes = excludedTypes;
    }


    public ParamIncludedTypeXmlElement getIncludedTypes() {
        return includedTypes;
    }

    @XmlElement(name = "IncludedTypes")
    public void setIncludedTypes(ParamIncludedTypeXmlElement includedTypes) {
        this.includedTypes = includedTypes;
    }

    public ArrayList<ParamXmlElement> getAdds() {
        return adds;
    }

    @XmlElement(name="Add")
    public void setAdds(ArrayList<ParamXmlElement> adds) {
        this.adds = adds;
    }

    @XmlAttribute
    public String getType() {
        return type;
    }

    public void setType(String type){
        this.type = type;
    }


}
